
package eu.dnetlib.dhp.rdfconverter.bioschema.model;

import java.util.List;

import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;

import eu.dnetlib.dhp.rdfconverter.utils.CustomPropertyValueDeserializer;

@JsonIgnoreProperties(ignoreUnknown = true)
public class BioSchemaProtein {
	@JsonProperty("@id")
	private String id;
	@JsonProperty("@graph")
	private List<Entry> entryList;
	@JsonProperty("http://purl.org/pav/retrievedOn")
	private DateTimeType retrievedOn;

	public static class Entry {
		@JsonProperty("@id")
		private String id;
		@JsonProperty("@type")
//		private List<String> type;
		private String type;
		@JsonProperty("https://schema.org/identifier")
		private String identifier;
		@JsonProperty("https://schema.org/name")
		private String name;
		@JsonProperty("associatedDisease")
		private List<AssociatedDisease> associatedDisease;
		@JsonProperty("description")
		private String description;
		@JsonProperty("isEncodedByBioChemEntity")
		private String isEncodedByBioChemEntity;
		@JsonProperty("url")
		private String url;
		@JsonProperty("alternateName")
		private String alternateName;
		@JsonProperty("bioChemInteraction")
		private List<Link> bioChemInteraction;
		@JsonProperty("bioChemSimilarity")
		private List<Link> bioChemSimilarity;
		@JsonProperty("hasMolecularFunction")
		private String hasMolecularFunction;
		@JsonProperty("image")
		private String image;
		@JsonProperty("isInvolvedInBiologicalProcess")
		private String isInvolvedInBiologicalProcess;
		@JsonProperty("isPartOfBioChemEntity")
		private IsPartOfBioChemEntity isPartOfBioChemEntity;
		@JsonProperty("mainEntityOfPage")
		private Link mainEntityOfPage;
		@JsonProperty("https://schema.org/citation")
		private Citation citation;
		@JsonProperty("https://schema.org/sameAs")
		private List<Link> sameAs;
		@JsonProperty("https://schema.org/hasSequenceAnnotation")
		private List<Link> hasSequenceAnnotation;
		@JsonProperty("https://schema.org/additionalProperty")
		private List<Link> sequenceAnnotation;
		@JsonProperty("https://schema.org/value")
		@JsonDeserialize(using = CustomPropertyValueDeserializer.class)
		private Link propertyValue;
		@JsonProperty("https://schema.org/termCode")
		private String termCode;

		public String getId() {
			return id;
		}

		public void setId(String id) {
			this.id = id;
		}

		public String getType() {
			return type;
		}

		public void setType(String type) {
			this.type = type;
		}

		public String getName() {
			return name;
		}

		public void setName(String name) {
			this.name = name;
		}

		public List<Link> getSameAs() {
			return sameAs;
		}

		public void setSameAs(List<Link> sameAs) {
			this.sameAs = sameAs;
		}

		public String getIdentifier() {
			return identifier;
		}

		public void setIdentifier(String identifier) {
			this.identifier = identifier;
		}

		public String getDescription() {
			return description;
		}

		public void setDescription(String description) {
			this.description = description;
		}

		public String getIsEncodedByBioChemEntity() {
			return isEncodedByBioChemEntity;
		}

		public void setIsEncodedByBioChemEntity(String isEncodedByBioChemEntity) {
			this.isEncodedByBioChemEntity = isEncodedByBioChemEntity;
		}

		public String getUrl() {
			return url;
		}

		public void setUrl(String url) {
			this.url = url;
		}

		public String getAlternateName() {
			return alternateName;
		}

		public void setAlternateName(String alternateName) {
			this.alternateName = alternateName;
		}

		public List<Link> getBioChemInteraction() {
			return bioChemInteraction;
		}

		public void setBioChemInteraction(List<Link> bioChemInteraction) {
			this.bioChemInteraction = bioChemInteraction;
		}

		public List<Link> getBioChemSimilarity() {
			return bioChemSimilarity;
		}

		public void setBioChemSimilarity(List<Link> bioChemSimilarity) {
			this.bioChemSimilarity = bioChemSimilarity;
		}

		public String getHasMolecularFunction() {
			return hasMolecularFunction;
		}

		public void setHasMolecularFunction(String hasMolecularFunction) {
			this.hasMolecularFunction = hasMolecularFunction;
		}

		public String getImage() {
			return image;
		}

		public void setImage(String image) {
			this.image = image;
		}

		public String getIsInvolvedInBiologicalProcess() {
			return isInvolvedInBiologicalProcess;
		}

		public void setIsInvolvedInBiologicalProcess(String isInvolvedInBiologicalProcess) {
			this.isInvolvedInBiologicalProcess = isInvolvedInBiologicalProcess;
		}

		public List<AssociatedDisease> getAssociatedDisease() {
			return associatedDisease;
		}

		public void setAssociatedDisease(List<AssociatedDisease> associatedDisease) {
			this.associatedDisease = associatedDisease;
		}

		public IsPartOfBioChemEntity getIsPartOfBioChemEntity() {
			return isPartOfBioChemEntity;
		}

		public void setIsPartOfBioChemEntity(IsPartOfBioChemEntity isPartOfBioChemEntity) {
			this.isPartOfBioChemEntity = isPartOfBioChemEntity;
		}

		public Link getMainEntityOfPage() {
			return mainEntityOfPage;
		}

		public void setMainEntityOfPage(Link mainEntityOfPage) {
			this.mainEntityOfPage = mainEntityOfPage;
		}

		public List<Link> getHasSequenceAnnotation() {
			return hasSequenceAnnotation;
		}

		public void setHasSequenceAnnotation(List<Link> hasSequenceAnnotation) {
			this.hasSequenceAnnotation = hasSequenceAnnotation;
		}

		public List<Link> getSequenceAnnotation() {
			return sequenceAnnotation;
		}

		public void setSequenceAnnotation(List<Link> sequenceAnnotation) {
			this.sequenceAnnotation = sequenceAnnotation;
		}

		public Citation getCitation() {
			return citation;
		}

		public void setCitation(Citation citation) {
			this.citation = citation;
		}

		public Link getPropertyValue() {
			return propertyValue;
		}

		public void setPropertyValue(Link propertyValue) {
			this.propertyValue = propertyValue;
		}

		public String getTermCode() {
			return termCode;
		}

		public void setTermCode(String termCode) {
			this.termCode = termCode;
		}
	}

	public static class IsPartOfBioChemEntity {
		@JsonProperty("@type")
		private String type;
		@JsonProperty("url")
		private String url;

		public String getType() {
			return type;
		}

		public void setType(String type) {
			this.type = type;
		}

		public String getUrl() {
			return url;
		}

		public void setUrl(String url) {
			this.url = url;
		}
	}

	public static class AssociatedDisease {
		@JsonProperty("@type")
		private String type;
		@JsonProperty("name")
		private String name;
		@JsonProperty("code")
		private DeseaseCode code;
		@JsonProperty("id")
		private String id;

		public String getType() {
			return type;
		}

		public void setType(String type) {
			this.type = type;
		}

		public String getName() {
			return name;
		}

		public void setName(String name) {
			this.name = name;
		}

		public DeseaseCode getCode() {
			return code;
		}

		public void setCode(DeseaseCode code) {
			this.code = code;
		}

		public String getId() {
			return id;
		}

		public void setId(String id) {
			this.id = id;
		}
	}

	public static class DeseaseCode {
		@JsonProperty("@type")
		private String type;
		@JsonProperty("codeValue")
		private String codeValue;
		@JsonProperty("codingSystem")
		private String codingSystem;

		public String getType() {
			return type;
		}

		public void setType(String type) {
			this.type = type;
		}

		public String getCodeValue() {
			return codeValue;
		}

		public void setCodeValue(String codeValue) {
			this.codeValue = codeValue;
		}

		public String getCodingSystem() {
			return codingSystem;
		}

		public void setCodingSystem(String codingSystem) {
			this.codingSystem = codingSystem;
		}
	}

	public static class Link {
		@JsonProperty("@id")
		private String id;

		public String getId() {
			return id;
		}

		public void setId(String id) {
			this.id = id;
		}
	}

	public static class DateTimeType {
		@JsonProperty("@type")
		private String type;
		@JsonProperty("@value")
		private String value;

		public String getType() {
			return type;
		}

		public void setType(String type) {
			this.type = type;
		}

		public String getValue() {
			return value;
		}

		public void setValue(String value) {
			this.value = value;
		}
	}

	public static class Citation {
		@JsonProperty("@id")
		private String id;

		public String getId() {
			return id;
		}

		public void setId(String id) {
			this.id = id;
		}
	}

	public static class SequenceAnnotationId {
		@JsonProperty("@id")
		private String id;

		public String getId() {
			return id;
		}

		public void setId(String id) {
			this.id = id;
		}
	}

	public static class SequenceAnnotation {
		@JsonProperty("https://schema.org/additionalProperty")
		private List<PropertyValue> additionalProperty;

		public List<PropertyValue> getAdditionalProperty() {
			return additionalProperty;
		}

		public void setAdditionalProperty(List<PropertyValue> additionalProperty) {
			this.additionalProperty = additionalProperty;
		}
	}

	public static class PropertyValue {
		@JsonProperty("https://schema.org/value")
		private DefinedTerm definedTerm;

		public DefinedTerm getDefinedTerm() {
			return definedTerm;
		}

		public void setDefinedTerm(DefinedTerm definedTerm) {
			this.definedTerm = definedTerm;
		}
	}

	public static class DefinedTerm {
		@JsonProperty("@id")
		private String id;
		@JsonProperty("https://schema.org/termCode")
		private String termCode;
		@JsonProperty("https://schema.org/name")
		private String name;

		public String getId() {
			return id;
		}

		public void setId(String id) {
			this.id = id;
		}

		public String getTermCode() {
			return termCode;
		}

		public void setTermCode(String termCode) {
			this.termCode = termCode;
		}

		public String getName() {
			return name;
		}

		public void setName(String name) {
			this.name = name;
		}
	}

	public String getId() {
		return id;
	}

	public void setId(String id) {
		this.id = id;
	}

	public List<Entry> getEntryList() {
		return entryList;
	}

	public void setEntryList(List<Entry> entryList) {
		this.entryList = entryList;
	}

	public DateTimeType getRetrievedOn() {
		return retrievedOn;
	}

	public void setRetrievedOn(DateTimeType retrievedOn) {
		this.retrievedOn = retrievedOn;
	}
}
